sequencetools.negate_absolute_value_of_sequence_elements_cyclically
===================================================================

.. autofunction:: abjad.tools.sequencetools.negate_absolute_value_of_sequence_elements_cyclically.negate_absolute_value_of_sequence_elements_cyclically
